[![Lib upload](https://github.com/splightplatform/splight-lib/actions/workflows/libupload.yml/badge.svg)](https://github.com/splightplatform/splight-lib/actions/workflows/libupload.yml)

## How to install

For development

- `python setup.py develop`

For productive envs.

- `python setup.py install`

## Tests

```
pytest splight_lib/tests
```
